
in vec3 position_eye, normal_eye;
in vec2 texture_coordinates;
in vec3 fragPos;
uniform float jitter;
uniform vec3 light_pos[10];
uniform mat4 view;
uniform sampler2D basic_texture;
vec3 Ls = vec3 (1.0, 1.0, 0.0); // white specular colour
vec3 Ld = vec3 (0.5, 0.0, 0.5); // diffuse light colour
vec3 La = vec3 (0.2, 0.2, 0.2); // grey ambient colour
vec3 Ks = vec3 (1.0, 1.0, 1.0); // fully reflect specular light
vec3 Kd = vec3 (1.0, 1.0, 1.0); // diffuse surface reflectance
vec3 Ka = vec3 (0.0, 0.0, 0.0); // fully reflect ambient light
float specular_exponent = 10.0; // specular 'power'
out vec4 frag_color;
void main () {
	vec3 Ia = La * Ka;
	vec4 result = vec4(Ia, 1.0);
	for(int i = 0; i < 10; i++) {
		// get dist
		vec3 vPosToLight = fragPos - light_pos[i];
		float dist = length(vPosToLight);
		vPosToLight = normalize(vPosToLight);
		// diffuse light
		vec3 light_position_eye = vec3 (view * vec4 (light_pos[i], 1.0));
		vec3 distance_to_light_eye = light_position_eye - position_eye;
		vec3 direction_to_light_eye = normalize (distance_to_light_eye);
		float dot_prod = dot (direction_to_light_eye, normal_eye);
		dot_prod = max (dot_prod, 0.0);
		vec3 Id = Ld * Kd * dot_prod;
		// attenuation
		float radius = 25.0 + jitter;
		float attC = 1.0;
		float attL = 2.0 / radius;
		float attQ = 1.0 / (radius * radius);
		float attTotal = attC + attL * dist + attQ * dist * dist;
		// specular
		vec3 reflection_eye = reflect (-direction_to_light_eye, normal_eye);
		vec3 surface_to_viewer_eye = normalize (-position_eye);
		float dot_prod_specular = dot (reflection_eye, surface_to_viewer_eye);
		dot_prod_specular = max (dot_prod_specular, 0.0);
		float specular_factor = pow (dot_prod_specular, specular_exponent);
		vec3 Is = Ls * Ks * specular_factor;
		if( light_pos[i] != vec3(0,0,0) ) {
			float incr = radius / 10;
			if(dist > radius) {
				result += vec4(0,0,0,1);
			} else if(dist > radius - incr * 1) {
				result += (vec4(Ld,1)/2.6);
			} else if(dist > radius - incr * 2) {
				result += (vec4(Ld,1)/2.2);
			} else if(dist > radius - incr * 3) {
				result += (vec4(Ld,1)/1.8);
			} else if(dist > radius - incr * 4) {
				result += (vec4(Ld,1)/1.4);
			} else {
				result += vec4(Ld,1);
			}
		}
	}
	vec4 texel = texture2D (basic_texture, texture_coordinates);
	frag_color = result * texel;
}